@@ -43,7 +43,7 @@ class NBApi(FastAPI):
         async def metrics():
             return PlainTextResponse(pc.generate_latest())
 
-        self.get('/metrics')(metrics)
+        self.get('/metrics', include_in_schema=False)(metrics)
 
         async def handle_httperror(rec: Request, exc: StarletteHTTPException):
             return JSONResponse(
